#!/usr/bin/env bash
###############################################################################
#
#          Dell Inc. PROPRIETARY INFORMATION
# This software is supplied under the terms of a license agreement or
# nondisclosure agreement with Dell Inc. and may not
# be copied or disclosed except in accordance with the terms of that
# agreement.
#
# Copyright (c) 2013 Dell Inc. All Rights Reserved.
#
# Module Name:
#
#   dcism.sh
#
#
# Abstract/Purpose:
#
#   Interactive Custom Install Script to cutomize the iDRAC Service Module
#   RPM Package install.
#   This interactive script will enable the user to choose the optional
#   features and make them available on the local machine.
#
# Environment:
#
#   Linux
#
###############################################################################
# Operating system ("OS") types.
# These are the return values for the following function:
#     GetOSType
#
GBL_OS_TYPE_ERROR=0
GBL_OS_TYPE_UKNOWN=1
GBL_OS_TYPE_RHEL3=2
GBL_OS_TYPE_RHEL4=3
GBL_OS_TYPE_SLES10=4
GBL_OS_TYPE_RHEL5=5
GBL_OS_TYPE_SLES11=6
GBL_OS_TYPE_ESX40=7
GBL_OS_TYPE_ESX41=8
GBL_OS_TYPE_RHEL6=9

GBL_OS_TYPE_STRING=$GBL_OS_TYPE_UKNOWN
PATH_TO_RPMS_SUFFIX=""

SYSIDFILEPATH=""
LICENSEFILEPATH=""
LICENSEFILE="prereq/license_agreement.txt"


OPTION_COUNT=4
DCISM_FEATURE_ARRAY=([0]="Watchdog Instrumentation Service." [1]="Lifecycle Log Replication." [2]="Operating System Information." [3]="All features")

WATCHDOG_INDEX=0
LCLOG_INDEX=1
OSINFO_INDEX=2

DCISM_FEATURES_ENABLED_ARRAY=([$WATCHDOG_INDEX]="false" [$LCLOG_INDEX]="false" [$OSINFO_INDEX]="false" [3]="false")
DCISM_SECTIONS=([0]="dcwdfp" [1]="dclclfp" [2]="dcosfp")

FIRST_SCREEN=0
CLEAR_CONTINUE="no" 

ARCH="x86_64"
ISM_INI_FILE="/opt/dell/srvadmin/iSM/etc/ini/dcismdy64.ini"
SERVICES_SCRIPT="/etc/init.d/dcismeng"
SELECT_ALL="false"
AUTO_START="false"
EXPRESS="false"

# silent install options
SHORT_OPTS=([0]="w" [1]="l" [2]="o" [3]="x" [4]="a" [5]="i" [6]="d")
LONG_OPTS=([0]="watchdog" [1]="lclog" [2]="osinfo" [3]="express" [4]="autostart" [5]="install" [6]="delete")
SHORT_DEL="false"
SHORT_INSTALL="false"
MOD_CM=""

TEMP_INI_FILE="/opt/dell/srvadmin/iSM/tmpdcism.ini"
trap 'rm -rf $TEMP_INI_FILE > /dev/null 2>&1'   EXIT ERR

###############################################################################
# Function : Usage
#
## Display the usage messages
###############################################################################
function Usage {
cat <<EOF
Usage: ${0} [OPTION]...
iDRAC Service Module Install Utility. This Utility will run in the interactive 
mode if no options are given and runs silently if one or more options are given

Options:

[-h|--help]       Displays this help
[-i|--install]    Installs and enables the selected features.
[-x|--express]    Installs and enables all available features. 
                  Any other options passed will be ignored.
[-d|--delete]  	  Uninstall the iSM component.
[-w|--watchdog]   Enables the Watchdog Instrumentation Service.
[-l|--lclog]      Enables the Lifecycle Log Replication.
[-o|--osinfo]     Enables the Operating System Information. 
[-a|--autostart]  Start the installed service after the component has 
                  been installed.

EOF
  
  if [ -n "$1" ] && [ "$1" = "Help" ]
  then
	exit 0
  fi
  SetErrorAndInterrupt 10
}

###############################################################################
# Function : ShowLicense 
# Function will show license
#
###############################################################################
function ShowLicense()
{
   REQRPM=`rpm -qa | grep dcism`
  
   if [ -z $REQRPM ]
   then
       if [ -f "$LICENSEFILEPATH" ]
       then
           more "$LICENSEFILEPATH"
           echo ""
           echo -n "Do you agree to the above license terms? ('y' for yes | 'Enter' to exit): "
           read ANSWER 
           answer=`echo "${ANSWER}" | sed 's#^[[:space:]]*##; s#[[:space:]]*$##'`
           if echo "${answer}" | grep -qi "^y$" 
           then
               clear
           else
               exit 0
           fi
       fi
   fi
}
# check for help
    echo "${*}" | egrep "^.*--help.*$" >/dev/null 2>&1
    if [ $? == 0 ]; then
      Usage Help
    fi

    echo "${*}" | egrep "^.*-h.*$" >/dev/null 2>&1
    if [ $? == 0 ]; then
      Usage Help
    fi

# ensure sbin utilities are available in path, so that su will also work
export PATH=/usr/kerberos/sbin:/usr/local/sbin:/sbin:/usr/sbin:$PATH

# check for root privileges
if [ ${UID} != 0 ]; then
    echo "This utility requires root privileges"
    exit 1
    SetErrorAndInterrupt 1
fi

###############################################################################
# Function : SetErrorAndInterrupt
#
#   The "tee" command used to write log, continues execution after
#   the "tee" when any part of the utility exits. Additionally, global
#   variables do not seem to be updated when execution resumes. So, all
#   exit errors are mapped to the signal HUP. kill works very quickly
#   AFTER exit is called, so to allow user messages to output, sleep
#   was added.
###############################################################################
function SetErrorAndInterrupt
{
    FF_EXIT=$1
    sleep 1
    exit $FF_EXIT
    kill -HUP $$
}

###############################################
## Prompt
###############################################

function Prompt {
  MSG="${1}"

  # prompt and get response
  echo -n "${MSG}" 1>&2
  read RESP

  # remove leading/trailing spaces
  echo "${RESP}" | sed 's#^[[:space:]]*##; s#[[:space:]]*$##'
}

###############################################################################
##
## Function:    GetOSType
##
## Decription:  Determines the operating system type.
##
## Returns:     0 = No error
##
## Return Vars: GBL_OS_TYPE=[GBL_OS_TYPE_ERROR|
##                           GBL_OS_TYPE_UKNOWN|
##                           GBL_OS_TYPE_RHEL5|
##                           GBL_OS_TYPE_SLES10|
##                           GBL_OS_TYPE_SLES11|
##                           GBL_OS_TYPE_ESX40|
##                           GBL_OS_TYPE_ESX41]                ]
##                           GBL_OS_TYPE_RHEL6|
##              GBL_OS_TYPE_STRING=[RHEL5|SLES10|SLES11|ESX40|ESX41||RHEL6|UNKNOWN]
##
###############################################################################

GetOSType()
{
    # Set default values for return variables.
    GBL_OS_TYPE=${GBL_OS_TYPE_UKNOWN}
    GBL_OS_TYPE_STRING="UKNOWN"


    # check if operating system is RHEL5.
    if [ -f /etc/redhat-release ] && [ `grep -c "Tikanga" /etc/redhat-release` -gt 0 ]; then
        GBL_OS_TYPE=${GBL_OS_TYPE_RHEL5}
        GBL_OS_TYPE_STRING="RHEL5"
        PATH_TO_RPMS_SUFFIX=RHEL5
    elif [ -f /etc/redhat-release ] && [ `grep -c "Santiago" /etc/redhat-release` -gt 0 ]; then
        GBL_OS_TYPE=${GBL_OS_TYPE_RHEL6}
        GBL_OS_TYPE_STRING="RHEL6"
        PATH_TO_RPMS_SUFFIX=RHEL6
    # Else check if operating system is SLES.
    elif [ -f /etc/SuSE-release ]; then
        LOC_VERSION=`cat /etc/SuSE-release | grep "VERSION" | sed  -e 's#[^0-9]##g'`

        # Check if operating system is SLES10.
        if [ "${LOC_VERSION}" = "10" ]; then
            GBL_OS_TYPE=${GBL_OS_TYPE_SLES10}
            GBL_OS_TYPE_STRING="SLES10"
            PATH_TO_RPMS_SUFFIX=SLES10
        # Check if operating system is SLES11.
        elif [ "${LOC_VERSION}" = "11" ]; then
            GBL_OS_TYPE=${GBL_OS_TYPE_SLES11}
            GBL_OS_TYPE_STRING="SLES11"
            PATH_TO_RPMS_SUFFIX=SLES11
        fi
    fi

    return 0
}
######################## INI FUNCTIONS SECTION START #################

function ChangeINIKeyValue
{
	INI_FILENAME=$1
	SECTION=$2
	KEY=$3
	VALUE=$4

	FOUND_SECTION=1
	FOUND_KEY=1

	#do not execute without proper parameter count
	if [ ! $# -eq 4 ]
	then
		echo "Incorrect number of parameters"
		return 1	
	fi

	#exit if ini file not present
	if [ ! -f $INI_FILENAME ]
	then
		return 1
	fi


	#read file line by line until we hit the required section
	#and the required key. perform the job and break

	while read LINE
	do
   	 if [ $FOUND_SECTION == 0 ] && [ $FOUND_KEY == 0 ]
		then
		echo "$LINE" >> $TEMP_INI_FILE 
		continue
	fi

	#check if a section is found and set flag
	echo $LINE | grep -e "^\[${SECTION}\]$"> /dev/null 2>&1
	if [ $? == 0 ]
    then
		FOUND_SECTION=0
    fi
	
	#check if this line is the key required
	if [ $FOUND_SECTION == 0 ]
	then
		echo $LINE | grep -e "${KEY}" > /dev/null 2>&1
		if [ $? == 0 ]
    	then
			LINE=`echo "${LINE}" | sed "s/${KEY}=.*/${KEY}=${VALUE}/g"`
			FOUND_KEY=0
		fi
	fi
	echo "$LINE" >> $TEMP_INI_FILE  

	done < $INI_FILENAME

	cp -f $TEMP_INI_FILE $INI_FILENAME
	rm -f $TEMP_INI_FILE

	return 0
}

function GetINIKeyValue
{
	INI_FILENAME=$1
	SECTION=$2
	KEY=$3
	VALUE=""

	FOUND_SECTION=1
	FOUND_KEY=1

	#do not execute without proper parameter count
	if [ ! $# -eq 3 ]
	then
		echo "Incorrect number of parameters"
		return 1	
	fi

	#exit if ini file not present
	if [ ! -f $INI_FILENAME ]
	then
		return 1
	fi

	#read file line by line until we hit the required section
	#and the required key. perform the job and break

	while read LINE
	do
   	 if [ $FOUND_SECTION == 0 ] && [ $FOUND_KEY == 0 ]
		then
		break	
	fi

	#check if a section is found and set flag
	echo $LINE | grep -e "^\[${SECTION}\]$"> /dev/null 2>&1
	if [ $? == 0 ]
    then
		FOUND_SECTION=0
    fi
	
	#check if this line is the key required
	if [ $FOUND_SECTION == 0 ]
	then
		echo $LINE | grep -e "${KEY}" > /dev/null 2>&1
		if [ $? == 0 ] && [ $FOUND_SECTION == 0 ]
    	then
			VALUE=`echo "${LINE}" | awk -F= '{print$2}'`
			FOUND_KEY=0
			return $VALUE 
		fi
	fi
	done
	return ""
}
######################## INI FUNCTIONS SECTION END #################

function CheckiSMInstalled
{

	RPM_NAME=""

	RPM_NAME=`rpm -qa | grep "dcism"`
	if [ ! -z $RPM_NAME ]
	then
		FIRST_SCREEN=2
		return 0	
	fi
	return 1
}

###############################################################################
#  Function : PrintGreetings
#
###############################################################################

function PrintGreetings {
  cat <<EOF

#################################################
  
  OpenManage || iDRAC Service Module 

#################################################

EOF
}

function ShowInstallOptions
{
     if [ $FIRST_SCREEN == 2 ]
     then
  cat <<EOF
   The iDRAC Service Module is already installed. 
   Select from the available options below.

EOF
	return 0
     fi

echo "    Available feature options: "
echo ""
		ENABLED_PATT="[ ]"
	  #j is a 1 based index. This is the option number
      i=0
      j=1

      while [ $i -lt $OPTION_COUNT ] 
      do
     	if [ ${DCISM_FEATURES_ENABLED_ARRAY[$i]} == "true" ]
		then
			ENABLED_PATT="[x]" 
		else
			ENABLED_PATT="[ ]" 
		fi

      echo "   ${ENABLED_PATT} $j. ${DCISM_FEATURE_ARRAY[${i}]}"
         i=`expr $i + 1`
         j=`expr $j + 1`
      done

echo ""
echo ""
}

function ValidateUserSelection
{
    if [ $1 -gt 0 -a $1 -lt 5 ]; then
       return 0
	else
	   return 1
	fi
}

function toggle_feature_choice
{
	#this is because user selection in a 1 based index
	let "index=$1 - 1"
	
	#if all option was earlier selected
	if [ $1 != 4 ] && [ $SELECT_ALL == "true" ]
	then
		SELECT_ALL="false"
		for (( idx=0 ; idx<${OPTION_COUNT}; idx++ ));
		do
			DCISM_FEATURES_ENABLED_ARRAY[$idx]="false"
		done
	fi
	
	#regular flow if earlier selected, deselect now
	if [ ${DCISM_FEATURES_ENABLED_ARRAY[$index]} == "true" ]
	then
		DCISM_FEATURES_ENABLED_ARRAY[$index]="false"
	else
		DCISM_FEATURES_ENABLED_ARRAY[$index]="true"
	fi

	#if all option is now selected
	if [ $1 == 4 ]
	then
		SELECT_ALL="true"
		value="true"

		#Note we are using $index as the index variable.
		if [ ${DCISM_FEATURES_ENABLED_ARRAY[$index]} == "true" ]
		then
			value="true"
		else
			value="false"
		fi

		for (( idx=0 ; idx<${OPTION_COUNT}; idx++ ));
		do
			DCISM_FEATURES_ENABLED_ARRAY[$idx]=$value
		done
	fi
}

###############################################################################
# Function : AddLongOpt
#
## Process long command line options
###############################################################################
function AddLongOpt {

  if [ ${1} == "express" ]; then
	EXPRESS="true"
  elif [ ${1} == "watchdog" ]; then
	DCISM_FEATURES_ENABLED_ARRAY[$WATCHDOG_INDEX]="true"
  elif [ ${1} == "lclog" ]; then
	DCISM_FEATURES_ENABLED_ARRAY[$LCLOG_INDEX]="true"
  elif [ ${1} == "osinfo" ]; then
	DCISM_FEATURES_ENABLED_ARRAY[$OSINFO_INDEX]="true"
  elif [ ${1} == "install" ]; then
	SHORT_INSTALL="true"
  elif [ ${1} == "delete" ]; then
	SHORT_DEL="true"
      elif [ ${1} == "autostart" ]; then
    AUTO_START="true"
  fi
}

###############################################################################
# Function : AddShortOpt
#
## Process short command line options
###############################################################################
function AddShortOpt {

  for SHORT_OPT in `echo "${1}" | sed "s/[a-z]/& /g"`; do
    if [ ${SHORT_OPT} == "x" ]; then
		EXPRESS="true"
    elif [ ${SHORT_OPT} == "w" ]; then
		DCISM_FEATURES_ENABLED_ARRAY[$WATCHDOG_INDEX]="true"
    elif [ ${SHORT_OPT} == "l" ]; then
		DCISM_FEATURES_ENABLED_ARRAY[$LCLOG_INDEX]="true"
    elif [ ${SHORT_OPT} == "o" ]; then
		DCISM_FEATURES_ENABLED_ARRAY[$OSINFO_INDEX]="true"
    elif [ ${SHORT_OPT} == "d" ]; then
		SHORT_DEL="true"
    elif [ ${SHORT_OPT} == "i" ]; then
		SHORT_INSTALL="true"
    elif [ ${SHORT_OPT} == "a" ]; then
		AUTO_START="true"
    fi
  done
}

###############################################################################
# Function : ValidateOpts
#
## Validate command line options
###############################################################################
function ValidateOpts {
  if [ $# -gt 0 ]; then
    # invald characters
    #BY  added //,.,_,0-9,A-Z
    echo "${*}" | sed "s/ //g" | egrep "^[-/._a-z0-9//]+$" >/dev/null 2>&1
    if [ $? != 0 ]; then
      echo "Invalid Options, please see the usage below"
      echo ""
      Usage
    fi
    
    MOD_CM=$*

# replace  $* by $MOD_CM which does not contain --prefix <path>
for param in $MOD_CM; do
      # check for long option
      echo "${param}" | egrep "^--[a-z\-]+$" >/dev/null 2>&1
      if [ $? == 0 ]; then
        GOOD_LONG_OPT=1
        for (( i=0 ; i<${#LONG_OPTS[*]} ; i++ )); do
          if [ ${param} == "--${LONG_OPTS[i]}" ]; then
            GOOD_LONG_OPT=0
            AddLongOpt ${LONG_OPTS[i]}
            break
          fi
        done

        if [ ${GOOD_LONG_OPT} != 0 ]; then
          echo "Invalid Option ${param}, please see the usage below"
          Usage
        fi
      else
        # check for short option
        VALID_SHORT_OPTS=`echo "${SHORT_OPTS[*]}" | sed "s/ //g"`
        echo "${param}" | egrep "^-[${VALID_SHORT_OPTS}]+$" >/dev/null 2>&1
        if [ $? == 0 ]; then
          TEMP_OPT=`echo "${param}" | sed "s/-//"`
          AddShortOpt ${TEMP_OPT}
        else
          echo "Invalid Option ${param}, please see the usage below"
          Usage
        fi
      fi
    done
  fi
}
###############################################################################
#
#  function CheckForMultipleSelection
#
#
#
###############################################################################

function CheckForMultipleSelection {
    # remove any space characters
    STRIPPED_INPUT=`echo "$1" | sed "s/ //g"`

    OPTPKGARRLEN=4
    ARR_IDX=1
    # only process multiple selection less or eq to arr len
    while [ ! $ARR_IDX -gt $OPTPKGARRLEN ] && [ ! -z "$STRIPPED_INPUT" ];
    do
        INDEX=`expr index "$STRIPPED_INPUT" ","`
        LEN=`expr length $STRIPPED_INPUT`
        if [ $INDEX == 0 ];
        then
            ValidateUserSelection $STRIPPED_INPUT
            if [ $? == 0 ];
            then
                #UpdatePkgSlection
				toggle_feature_choice $STRIPPED_INPUT
            fi
            break
        elif [ $INDEX -lt $LEN ] || [ $INDEX == $LEN ];
        then
            INDEX=`expr $INDEX - 1`
            NUM_INPUT=`expr substr "$STRIPPED_INPUT" 1 $INDEX`
            if [ ! -z "$NUM_INPUT" ];
            then
                ValidateUserSelection $NUM_INPUT
                if [ $? == 0 ];
                then
                    #UpdatePkgSlection
					toggle_feature_choice $NUM_INPUT
                fi
                INDEX=`expr $INDEX + 2`
                STRIPPED_INPUT=`expr substr "$STRIPPED_INPUT" $INDEX $LEN`
                ARR_IDX=`expr $ARR_IDX + 1`
            else
                break
            fi
        else
           break
        fi
    done
}

function TakeUsersInputOnOptions
{
    if [ $FIRST_SCREEN == 0 ]
    then
    cat <<EOF
  Enter the number to select/deselect a feature from the above list.
  Enter q to quit.

EOF
    elif [ $FIRST_SCREEN == 1 ]
    then
    cat <<EOF
  Enter the number to select/deselect a feature 
        ( multiple feature selection should be comma separated)
  Enter i to install the selected features.
  Enter q to quit.

EOF
   else 
        #Handle uninstall and upgrade here
   cat <<EOF

  Enter d to uninstall the component.
  Enter q to quit.

EOF

    fi

    opt_pkg_index=`Prompt "  Enter : "`

    # check if number
    if [ `echo $opt_pkg_index | egrep '^[1-4]+$' ` ]; then
        ValidateUserSelection $opt_pkg_index
        if [ $? == 0 ]; then
            FIRST_SCREEN=1
			CLEAR_CONTINUE="yes"
			toggle_feature_choice $opt_pkg_index
        fi
     else
        opt_pkg_index=`echo "$opt_pkg_index" | tr 'a-z' 'A-Z'`
        if [ "$opt_pkg_index" == "Q" ]; then
            kill -EXIT $$
            sleep 1
            exit 0
        elif [ "$opt_pkg_index" == "D" ]; then
            #  UnInstallPackages
	       CLEAR_CONTINUE="no" 
	    	#"${SERVICES_SCRIPT}" stop 
			rpm -e dcism
		    ldconfig
	       exit 0
        elif [ "$opt_pkg_index" == "I" ]; then
            #  InstallPackages
			CLEAR_CONTINUE="no" 
    		rpm -Uvh $SYSIDFILEPATH/$GBL_OS_TYPE_STRING/$ARCH/dcism*.rpm
      else
            # check for multiple selection, comma separated
            opt_pkg_index=`echo "$opt_pkg_index" | sed "s/ //g"`
            if [ `echo $opt_pkg_index | egrep '^[1-4,]+$' ` ]; then
                CheckForMultipleSelection $opt_pkg_index
                if [ $? != 0 ]; then
                    FIRST_SCREEN=0
                 else
                    FIRST_SCREEN=1
					CLEAR_CONTINUE="yes" 
                fi
            else
                echo "Unknown option."
                echo "Press any key to continue..."
				read
				CLEAR_CONTINUE="yes" 
            fi
    fi
    fi

    if [ $CLEAR_CONTINUE == "yes" ]; then
        # clear the screen and start over
        clear
        PrintGreetings
		ShowInstallOptions
        TakeUsersInputOnOptions
    fi

	return 0
}

###############################################################################
# Function : GetPathToScript
#
# extracts the path to the script, this path will be used to locate
# the rpms repository on the CD or on the system
#
###############################################################################

function GetPathToScript () 
{
    # $1 is the path to the script, inluding the script name
    REPLACE_ANY_SPACES=`echo "$1" | sed "s/ /\\\ /"`
    PATH_TO_SCRIPT=`dirname "$REPLACE_ANY_SPACES"`
    SCRIPTNAME=`basename $1`

    CURDIR=`pwd | sed "s/ /\\\ /"`
    cd "$PATH_TO_SCRIPT"
    SYSIDFILEPATH="`pwd | sed "s/ /\\\ /"`"

    LICENSEFILEPATH="$SYSIDFILEPATH/$LICENSEFILE"

    cd "$CURDIR"
}

function PerformPrereqChecks
{
   . $SYSIDFILEPATH/prereq/CheckSystemType.sh $SYSIDFILEPATH

    IsThisSupportedGeneration
    # Check whether a valid system ID is available and is a supported DELL server
    if [ $? != 0 ]; then
	   echo "Unsupported system"
	   SetErrorAndInterrupt 2	
    fi
	ARCH=`uname -i`

    # operating system check
    GetOSType
    if [ "${GBL_OS_TYPE}" = "${GBL_OS_TYPE_UKNOWN}" ] || [ "${GBL_OS_TYPE}" = "${GBL_OS_TYPE_ERROR}" ] || [ $ARCH != "x86_64" ]; then
        # Operating system type is unknown, or an error occurred trying to
        # determine the operating system type. Exit with Error 2
   cat <<EOF
     Unrecognized Operating System or Architecture. This script cannot 
     continue with the installation. Select rpms from the OS folder in 
     the media that closely matches this Operating System to continue 
     with the manual install.
EOF
        SetErrorAndInterrupt 2
    fi

	#check whether iSM is already installed
	CheckiSMInstalled
}

function PerformPostInstall
{
	#check flag if rpm install was successful
		#check whether is installed or not
		CheckiSMInstalled
		if [ $? == 0 ]
		then
			#always set this parameter to false
			ChangeINIKeyValue "${ISM_INI_FILE}" "Agent Manager" "InstallerConsumed.enabled" "false" 

			#using a new variable because OPTION_COUNT is 1 count extra for all features
			OPTIONS=3
			index=0
			while [ $index -lt $OPTIONS ]
			do
				ChangeINIKeyValue "${ISM_INI_FILE}" "${DCISM_SECTIONS[$index]}" "feature.enabled" "${DCISM_FEATURES_ENABLED_ARRAY[$index]}"
         		index=`expr $index + 1`
			done

	#if this is a silent install
	if [ ! -z "${MOD_CM}" ]
	then
		if [ $AUTO_START == "true" ]
		then 
		    ldconfig
	    	"${SERVICES_SCRIPT}" start
		fi
	else
cat <<EOF

   Do you want the services started?

EOF
    sa_start=`Prompt "   Press ('y' for yes | 'Enter' to exit): "`

  # now start if 'yes'
  if echo "${sa_start}" | grep -qi "^y$" ; then
    ldconfig
    "${SERVICES_SCRIPT}" start
    echo ""
	fi
  fi
		fi
}

function InstallPackageSilent
{
	CheckiSMInstalled

	if [ $? != 0 ]
    then
        rpm -Uvh $SYSIDFILEPATH/$GBL_OS_TYPE_STRING/$ARCH/dcism*.rpm
        PerformPostInstall
    else
        echo "Service Module already installed"
    fi
}

function UninstallPackageSilent
{
	#"${SERVICES_SCRIPT}" stop
	rpm -e dcism
	ldconfig
}

###############################################################################
# Function : Main
#
# This is the starting point for the script, this
# function invokes other functions in the required
# order
###############################################################################
function Main
{ 
    CheckiSMInstalled

    if [ $? != 0 ]
    then
       PerformPrereqChecks
    fi

    # get the path and the script name
#    GetPathToScript "$0"

    #Show License if there are no options passed
    if [ -z "$1" ]
    then
       ShowLicense
    fi

    # process any options passed
    if [ $# -gt 0 ];
    then
      # process options
     ValidateOpts $*
    fi

    # block older version
#    BlockOnOldOM

    # system id check
#    CheckSystemID

    # process any options passed
    #as MOD_CM Contains filtered command line options i.e other than --prefix
    if [  -n "${MOD_CM}" ]; then

      # if already installed, should be able to add comps OR upgrade
#      DetectPreviousInstall "silent"

      # install or uninstall
		if [ $SHORT_DEL == "true" ]
		then
			UninstallPackageSilent
		else
			InstallPackageSilent
		fi
    else
      # clear screen and print greetings
	    clear
     # PrintGreetings
    	PrintGreetings 
      # list the optional features that user can choose from
	    ShowInstallOptions
      # read users input on the optional packages
	    TakeUsersInputOnOptions
	  # if the install or upgrade was successful, run post install
		PerformPostInstall
    fi

}

GetPathToScript $0

Main $* 2>&1

exit 0
